#!/bin/sh
# (C) Copyright 2005- ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
#
# In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
# virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.

. ./include.ctest.sh

${examples_dir}/c_grib_keys_iterator ${data_dir}/reduced_latlon_surface.grib1 > /dev/null

${examples_dir}/c_grib_keys_iterator ${data_dir}/regular_gaussian_model_level.grib1 > /dev/null

${examples_dir}/c_grib_keys_iterator ${data_dir}/mixed.grib > /dev/null
